THIS IS FOR EDUCATIONAL PURPOSES ONLY OR IF YOU HAVE CONSENT TO USE THAT SITES INFO!

`pip install WebProcessor`

GeckoDriver
- This will be installed automatically on first run

https://github.com/TheBlockNinja/WebProcessor

